summaryrefslogtreecommitdiffstats
path: root/kexi/3rdparty/kexisql3/src/expr.c
diff options
context:
space:
mode:
Diffstat (limited to 'kexi/3rdparty/kexisql3/src/expr.c')
-rw-r--r--kexi/3rdparty/kexisql3/src/expr.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/kexi/3rdparty/kexisql3/src/expr.c b/kexi/3rdparty/kexisql3/src/expr.c
index 9d079e1b..ac209552 100644
--- a/kexi/3rdparty/kexisql3/src/expr.c
+++ b/kexi/3rdparty/kexisql3/src/expr.c
@@ -1018,15 +1018,15 @@ static int lookupName(
}
/* If a column from a table in pSrcList is referenced, then record
** this fact in the pSrcList.a[].colUsed bittqmask. Column 0 causes
** bit 0 to be set. Column 1 sets bit 1. And so forth. If the
** column number is greater than the number of bits in the bittqmask
** then set the high-order bit of the bittqmask.
*/
if( pExpr->iColumn>=0 && pMatch!=0 ){
int n = pExpr->iColumn;
- if( n>=sizeof(Bittqmask)*8 ){
- n = sizeof(Bittqmask)*8-1;
+ if( n>=sizeof(Bitmask)*8 ){
+ n = sizeof(Bitmask)*8-1;
}
assert( pMatch->iCursor==pExpr->iTable );
pMatch->colUsed |= 1<<n;
@@ -1018,15 +1018,15 @@ static int lookupName(
}
/* If a column from a table in pSrcList is referenced, then record
- ** this fact in the pSrcList.a[].colUsed bittqmask. Column 0 causes
+ ** this fact in the pSrcList.a[].colUsed bitmask. Column 0 causes
** bit 0 to be set. Column 1 sets bit 1. And so forth. If the
@@ -1018,15 +1018,15 @@ static int lookupName(
** bit 0 to be set. Column 1 sets bit 1. And so forth. If the
- ** column number is greater than the number of bits in the bittqmask
- ** then set the high-order bit of the bittqmask.
+ ** column number is greater than the number of bits in the bitmask
+ ** then set the high-order bit of the bitmask.
*/
if( pExpr->iColumn>=0 && pMatch!=0 ){